# SDEE
A Python Package for Structural Dynamics & Earthquake Engineering

## Installation
```pip install sdee```

## How to use it?
Open terminal and type ```sdee```.

## License

© 2021 Mohsen Azimi

This repository is licensed under the MIT license. See LICENSE for details.